@@ -65,17 +65,6 @@ sub cc {
   }
 }
 
-sub cc_each {
-  my $self = shift;
-  if (@_) {
-    $self->{cc_each} = $_[0];
-    return $self;
-  }
-  else {
-    return $self->{cc_each};
-  }
-}
-
 sub ccflags {
   my $self = shift;
   if (@_) {
@@ -87,17 +76,6 @@ sub ccflags {
   }
 }
 
-sub ccflags_each {
-  my $self = shift;
-  if (@_) {
-    $self->{ccflags_each} = $_[0];
-    return $self;
-  }
-  else {
-    return $self->{ccflags_each};
-  }
-}
-
 sub optimize {
   my $self = shift;
   if (@_) {
@@ -109,17 +87,6 @@ sub optimize {
   }
 }
 
-sub optimize_each {
-  my $self = shift;
-  if (@_) {
-    $self->{optimize_each} = $_[0];
-    return $self;
-  }
-  else {
-    return $self->{optimize_each};
-  }
-}
-
 sub ld_optimize {
   my $self = shift;
   if (@_) {
@@ -263,6 +230,17 @@ sub force {
   }
 }
 
+sub before_compile {
+  my $self = shift;
+  if (@_) {
+    $self->{before_compile} = $_[0];
+    return $self;
+  }
+  else {
+    return $self->{before_compile};
+  }
+}
+
 sub before_link {
   my $self = shift;
   if (@_) {
@@ -843,53 +821,6 @@ B<Examples:>
   use Config;
   $config->cc($Config{cc});
 
-=head2 cc_each
-
-  my $cc_each = $config->cc_each;
-  $config->cc_each($cc_each);
-
-Get and set a callback that returns the compiler name for each source file. The call back receives L<SPVM::Bulder::Config> object and optional arguments as a hash reference.
-
-B<Optional Arguments:>
-
-=over 2
-
-=item * source_file
-
-Each source file.
-
-=item * class_name
-
-The class name
-
-=back
-
-If C<cc_each> is defined, the compiler use the return value of C<cc_each> as the compiler name instead of C<cc>.
-
-B<Examples:>
-  
-  $config->cc_each(sub {
-    my ($config, $args) = @_;
-    
-    # Source file
-    my $source_file = $args->{source_file};
-    
-    # Class name
-    my $class_name = $args->{class_name}
-    
-    my $cc;
-    # C source file
-    if ($source_file =~ /\.c$/) {
-      $cc = 'gcc';
-    }
-    # C++ source file
-    elsif ($source_file =~ /\.cpp$/) {
-      $cc = 'g++';
-    }
-    
-    return $cc;
-  });
-
 =head2 include_dirs
 
   my $include_dirs = $config->include_dirs;
@@ -948,63 +879,6 @@ B<Default:>
   # Other
   []
 
-=head2 ccflags_each
-
-  my $ccflags_each = $config->ccflags_each;
-  $config->ccflags_each($ccflags_each);
-
-Get and set a callback that returns the compiler flags for each source file. The call back receives L<SPVM::Bulder::Config> object and optional arguments as a hash reference.
-
-B<Optional Arguments:>
-
-=over 2
-
-=item * source_file
-
-Each source file.
-
-=item * class_name
-
-The class name
-
-=item * cc
-
-The compiler name that is the value after the process of the process of L<cc> or L<cc_each>.
-
-=back
-
-If C<ccflags_each> is defined, the compiler use the return value of C<ccflags_each> as the compiler flags instead of C<ccflags>.
-
-B<Examples:>
-  
-  $config->ccflags_each(sub {
-    my ($config, $source_file) = @_;
-
-    # Source file
-    my $source_file = $args->{source_file};
-    
-    # Class name
-    my $class_name = $args->{class_name}
-
-    # The compiler name
-    my $cc = $args->{cc};
-    
-    # ccflags
-    my $config_ccflags = $config->ccflags;
-    
-    my $ccflags = [];
-    # C source file
-    if ($source_file =~ /\.c$/) {
-      $ccflags = ['-DFoo', @$config_ccflags];
-    }
-    # C++ source file
-    elsif ($source_file =~ /\.cpp$/) {
-      $ccflags = ['-DBar', @$config_ccflags];
-    }
-    
-    return $ccflags;
-  });
-
 =head2 optimize
 
   my $optimize = $config->optimize;
@@ -1020,63 +894,6 @@ B<Examples:>
   $config->optimize('-O2');
   $config->optimize('-g3 -O0');
 
-=head2 optimize_each
-
-  my $optimize_each = $config->optimize_each;
-  $config->optimize_each($optimize_each);
-
-Get and set a callback that returns the value of optimize for each source file. The callback receives L<SPVM::Bulder::Config> object and optional arguments as a hash reference.
-
-B<Optional Arguments:>
-
-=over 2
-
-=item * source_file
-
-Each source file.
-
-=item * class_name
-
-The class name
-
-=item * cc
-
-The compiler name that is the value after the process of the process of L<cc> or L<cc_each>.
-
-=back
-
-If C<optimize_each> is defined, the compiler use the return value of C<optimize_each> as the compiler flags instead of C<optimize>.
-
-B<Examples:>
-  
-  $config->optimize_each(sub {
-    my ($config, $source_file) = @_;
-
-    # Source file
-    my $source_file = $args->{source_file};
-    
-    # Class name
-    my $class_name = $args->{class_name}
-
-    # The compiler name
-    my $cc = $args->{cc};
-    
-    # optimize
-    my $config_optimize = $config->optimize;
-    
-    my $optimize = [];
-    # C source file
-    if ($source_file =~ /\.c$/) {
-      $optimize = '-O3';
-    }
-    # C++ source file
-    elsif ($source_file =~ /\.cpp$/) {
-      $optimize = '-O3';
-    }
-    
-    return $optimize;
-  });
-
 =head2 source_files
 
   my $source_files = $config->source_files;
@@ -1161,6 +978,23 @@ Get and set the flag to force compiles and links without caching. The default is
 
 C<undef> means forcing is not determined by config.
 
+=head2 before_compile
+
+  my $before_compile = $config->before_compile;
+  $config->before_compile($before_compile);
+
+Get and set the callback that is executed before the compile. The callback receives C<SPVM::Builder::Config> object and the L<SPVM::Builder::CompileInfo> object used by the compileer.
+
+B<Examples:>
+
+  $config->before_compile(sub {
+    my ($config, $compile_info) = @_;
+    
+    my $cc = $compile_info->cc;
+    
+    # Do something
+  });
+
 =head2 before_link
 
   my $before_link = $config->before_link;
